@@ -1,6 +1,6 @@
 #######################################################################
-# $Date: 2007-06-03 02:17:24 -0700 (Sun, 03 Jun 2007) $
-# $Revision: 79 $
+# $Date: 2007-06-03 14:04:10 -0700 (Sun, 03 Jun 2007) $
+# $Revision: 85 $
 # $Author: david.romano $
 # ex: set ts=8 sw=4 et
 #########################################################################
@@ -10,7 +10,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.3.0');
+use version; our $VERSION = qv('0.3.1');
 
 sub base { return shift->{'base'}; }
 
@@ -28,8 +28,7 @@ sub new {
 sub create_token {
     my $self = shift;
     my $token;
-    my $orig_format = $self->base->format;
-    my $orig_parse  = $self->base->parse; 
+    my ( $format, $parse ) = ( $self->base->format, $self->base->parse );
 
     $self->base->format('JSON');
     $self->base->parse(0);
@@ -37,11 +36,11 @@ sub create_token {
     $token = $self->base->call( 'auth.createToken', @_ );
     $token =~ s/\W//g;
 
-    $self->base->format($orig_format);
-    $self->base->parse($orig_parse);
+    $self->base->format($format);
+    $self->base->parse($parse);
 
     return $token;
-}
+} 
 
 sub get_session {
     my $self = shift;
@@ -49,22 +48,22 @@ sub get_session {
     my $token = shift;
     if ( $self->base->desktop ) {
         $token ||= $self->base->create_token;
-        $self->base->server_uri( _make_secure( $self->base->server_uri ) );
+        (my $uri_https = $self->base->server_uri) =~ s{http://}{https://}mx;
+        $self->base->server_uri( $uri_https );
     }
     else {
         $token ||= $self->base->secret;
     }
 
-    my $orig_format = $self->base->format;
-    my $orig_parse  = $self->base->parse; 
+    my ( $format, $parse ) = ( $self->base->format, $self->base->parse );
 
     $self->base->format('JSON');
     $self->base->parse(0);
 
     my $response = $self->base->call( 'auth.getSession', auth_token => $token );
 
-    $self->base->format($orig_format);
-    $self->base->parse($orig_parse);
+    $self->base->format($format);
+    $self->base->parse($parse);
 
     my %field = qw(
         session_key     session_key
@@ -74,7 +73,8 @@ sub get_session {
 
     if ( $self->base->desktop ) {
         $field{'secret'} = 'secret';
-        $self->base->server_uri( _make_unsecure( $self->base->server_uri ) );
+        (my $uri_http = $self->base->server_uri) =~ s{https://}{http://}mx;
+        $self->base->server_uri( $uri_http );
     }
 
     while ( my ( $key, $val ) = each %field ) {
@@ -118,7 +118,11 @@ sub login {
         $token = ( $self->base->mech->uri =~ /auth_token=(.+)$/ )[0]
     }
     elsif ( $self->base->mech->content !~ m{Logout</a>}mix ) {
-        confess "Unable to login to Facebook using WWW::Mechanize\n";
+        my $error = "Unable to login to Facebook using WWW::Mechanize";
+        $error .= ': '.$self->base->mech->content if $self->base->debug;
+
+        confess $error if $self->base->throw_errors;
+        carp $error;
     }
 
     $self->base->mech->agent($agent);
@@ -131,18 +135,6 @@ sub logout {
         { confirm => 1 } );
 }
 
-sub _make_secure {
-    my $uri = shift;
-    $uri =~ s{http://}{https://}mx;
-    return $uri;
-}
-
-sub _make_unsecure {
-    my $uri = shift;
-    $uri =~ s{https://}{http://}mx;
-    return $uri;
-}
-
 1;
 __END__
 
@@ -150,17 +142,14 @@ __END__
 
 WWW::Facebook::API::Auth - Authentication utilities for Client
 
-
 =head1 VERSION
 
-This document describes WWW::Facebook::API::Auth version 0.3.0
-
+This document describes WWW::Facebook::API::Auth version 0.3.1
 
 =head1 SYNOPSIS
 
     use WWW::Facebook::API;
 
-
 =head1 DESCRIPTION
 
 Methods for accessing auth with L<WWW::Facebook::API>
@@ -206,33 +195,22 @@ http://developers.facebook.com/documentation.php?v=1.0&doc=auth )
 
 =back
 
-
-=head1 INTERNAL FUNCTIONS
+=head1 DIAGNOSTICS
 
 =over
 
-=item _make_secure
+=item C< Unable to login to Facebook using WWW::Mechanize: %s >
 
-Changes the server_uri to https for C<get_session>.
-
-=item _make_unsecure
-
-Changes the server_uri back to http at the end of C<get_session>.
+The login() method was not able to sign in to Facebook using WWW::Mechanize.
+The HTML for the page that was retrieve is returned if in debugging mode.
 
 =back
 
-
-=head1 DIAGNOSTICS
-
-None.
-
-
 =head1 CONFIGURATION AND ENVIRONMENT
 
 WWW::Facebook::API::Auth requires no configuration files or
 environment variables.
 
-
 =head1 DEPENDENCIES
 
 See L<WWW::Facebook::API>
@@ -241,7 +219,6 @@ See L<WWW::Facebook::API>
 
 None.
 
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
@@ -250,12 +227,10 @@ Please report any bugs or feature requests to
 C<bug-www-facebook-api@rt.cpan.org>, or through the web interface at
 L<http://rt.cpan.org>.
 
-
 =head1 AUTHOR
 
 David Romano  C<< <unobe@cpan.org> >>
 
-
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (c) 2007, David Romano C<< <unobe@cpan.org> >>. All rights reserved.
@@ -263,7 +238,6 @@ Copyright (c) 2007, David Romano C<< <unobe@cpan.org> >>. All rights reserved.
 This module is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself. See L<perlartistic>.
 
-
 =head1 DISCLAIMER OF WARRANTY
 
 BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
